shouldSkipFile method

bool shouldSkipFile(
  1. String path
)

Returns true if the file at path should be skipped by this analyzer.

Called before analysis to exclude files or directories from this rule.

Implementation

bool shouldSkipFile(String path) {
  return false;
}