DocumentationUtils class
Utility functions for checking documentation comments.
This class provides shared documentation validation logic used by multiple analyzers (e.g., document_enum, document_interface) to reduce code duplication.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
hasDocumentation(
Comment? comment) → bool -
Returns true if the comment contains valid
///documentation.